@@ -1,18 +1,18 @@
 var searchData=
 [
-  ['read_0',['read',['../classsf_1_1SoundFileReader.html#a3b7d86769ea07e24e7b0f0486bed7591',1,'sf::SoundFileReader::read()'],['../classsf_1_1FileInputStream.html#ad1e94c4152429f485db224c44ee1eb50',1,'sf::FileInputStream::read()'],['../classsf_1_1InputStream.html#a8dd89c74c1acb693203f50e750c6ae53',1,'sf::InputStream::read()'],['../classsf_1_1MemoryInputStream.html#adff5270c521819639154d42d76fd4c34',1,'sf::MemoryInputStream::read()'],['../classsf_1_1InputSoundFile.html#a83d6f64617456601edeb0daf9d14a17f',1,'sf::InputSoundFile::read()']]],
+  ['read_0',['read',['../classsf_1_1InputSoundFile.html#a83d6f64617456601edeb0daf9d14a17f',1,'sf::InputSoundFile::read()'],['../classsf_1_1SoundFileReader.html#a3b7d86769ea07e24e7b0f0486bed7591',1,'sf::SoundFileReader::read()'],['../classsf_1_1FileInputStream.html#ad1e94c4152429f485db224c44ee1eb50',1,'sf::FileInputStream::read()'],['../classsf_1_1InputStream.html#a8dd89c74c1acb693203f50e750c6ae53',1,'sf::InputStream::read()'],['../classsf_1_1MemoryInputStream.html#adff5270c521819639154d42d76fd4c34',1,'sf::MemoryInputStream::read()']]],
   ['receive_1',['receive',['../classsf_1_1TcpSocket.html#a90ce50811ea61d4f00efc62bb99ae1af',1,'sf::TcpSocket::receive(void *data, std::size_t size, std::size_t &amp;received)'],['../classsf_1_1TcpSocket.html#aa655352609bc9804f2baa020df3e7331',1,'sf::TcpSocket::receive(Packet &amp;packet)'],['../classsf_1_1UdpSocket.html#ade9ca0f7ed7919136917b0b997a9833a',1,'sf::UdpSocket::receive(void *data, std::size_t size, std::size_t &amp;received, IpAddress &amp;remoteAddress, unsigned short &amp;remotePort)'],['../classsf_1_1UdpSocket.html#afdd5c655d00c96222d5b477fc057a22b',1,'sf::UdpSocket::receive(Packet &amp;packet, IpAddress &amp;remoteAddress, unsigned short &amp;remotePort)']]],
-  ['rect_2',['rect',['../classsf_1_1Rect.html#a27fdf85caa6d12caeeff78913cc59936',1,'sf::Rect::Rect(const Vector2&lt; T &gt; &amp;position, const Vector2&lt; T &gt; &amp;size)'],['../classsf_1_1Rect.html#a6fff2bb7e93677839461a66bc2957de0',1,'sf::Rect::Rect(const Rect&lt; U &gt; &amp;rectangle)'],['../classsf_1_1Rect.html#a15cdbc5a1aed3a8fc7be1bd5004f19f9',1,'sf::Rect::Rect(T rectLeft, T rectTop, T rectWidth, T rectHeight)'],['../classsf_1_1Rect.html#a0f87ebaef9722a6222fd2e04ce8efb37',1,'sf::Rect::Rect()']]],
+  ['rect_2',['Rect',['../classsf_1_1Rect.html#a0f87ebaef9722a6222fd2e04ce8efb37',1,'sf::Rect::Rect()'],['../classsf_1_1Rect.html#a15cdbc5a1aed3a8fc7be1bd5004f19f9',1,'sf::Rect::Rect(T rectLeft, T rectTop, T rectWidth, T rectHeight)'],['../classsf_1_1Rect.html#a27fdf85caa6d12caeeff78913cc59936',1,'sf::Rect::Rect(const Vector2&lt; T &gt; &amp;position, const Vector2&lt; T &gt; &amp;size)'],['../classsf_1_1Rect.html#a6fff2bb7e93677839461a66bc2957de0',1,'sf::Rect::Rect(const Rect&lt; U &gt; &amp;rectangle)']]],
   ['rectangleshape_3',['RectangleShape',['../classsf_1_1RectangleShape.html#a83a2be157ebee85c95ed491c3e78dd7c',1,'sf::RectangleShape']]],
   ['registercontextdestroycallback_4',['registerContextDestroyCallback',['../classsf_1_1GlResource.html#ab171bdaf5eb36789da14b30a846db471',1,'sf::GlResource']]],
   ['registerreader_5',['registerReader',['../classsf_1_1SoundFileFactory.html#aeee396bfdbb6ac24c57e5c73c30ec105',1,'sf::SoundFileFactory']]],
   ['registerwriter_6',['registerWriter',['../classsf_1_1SoundFileFactory.html#abb6e082ea3fedf22c8648113d1be5755',1,'sf::SoundFileFactory']]],
   ['remove_7',['remove',['../classsf_1_1SocketSelector.html#a98b6ab693a65b82caa375639232357c1',1,'sf::SocketSelector']]],
   ['renamefile_8',['renameFile',['../classsf_1_1Ftp.html#a8f99251d7153e1dc26723e4006deb764',1,'sf::Ftp']]],
-  ['renderstates_9',['renderstates',['../classsf_1_1RenderStates.html#a39f94233f464739d8d8522f3aefe97d0',1,'sf::RenderStates::RenderStates(const Shader *theShader)'],['../classsf_1_1RenderStates.html#ab5eda13cd8c79c74eba3b1b0df817d67',1,'sf::RenderStates::RenderStates(const BlendMode &amp;theBlendMode, const Transform &amp;theTransform, const Texture *theTexture, const Shader *theShader)'],['../classsf_1_1RenderStates.html#a8f4ca3be0e27dafea0c4ab8547439bb1',1,'sf::RenderStates::RenderStates(const Texture *theTexture)'],['../classsf_1_1RenderStates.html#acac8830a593c8a4523ac2fdf3cac8a01',1,'sf::RenderStates::RenderStates(const BlendMode &amp;theBlendMode)'],['../classsf_1_1RenderStates.html#a885bf14070d0d5391f062f62b270b7d0',1,'sf::RenderStates::RenderStates()'],['../classsf_1_1RenderStates.html#a3e99cad6ab05971d40357949930ed890',1,'sf::RenderStates::RenderStates(const Transform &amp;theTransform)']]],
+  ['renderstates_9',['RenderStates',['../classsf_1_1RenderStates.html#a885bf14070d0d5391f062f62b270b7d0',1,'sf::RenderStates::RenderStates()'],['../classsf_1_1RenderStates.html#acac8830a593c8a4523ac2fdf3cac8a01',1,'sf::RenderStates::RenderStates(const BlendMode &amp;theBlendMode)'],['../classsf_1_1RenderStates.html#a3e99cad6ab05971d40357949930ed890',1,'sf::RenderStates::RenderStates(const Transform &amp;theTransform)'],['../classsf_1_1RenderStates.html#a8f4ca3be0e27dafea0c4ab8547439bb1',1,'sf::RenderStates::RenderStates(const Texture *theTexture)'],['../classsf_1_1RenderStates.html#a39f94233f464739d8d8522f3aefe97d0',1,'sf::RenderStates::RenderStates(const Shader *theShader)'],['../classsf_1_1RenderStates.html#ab5eda13cd8c79c74eba3b1b0df817d67',1,'sf::RenderStates::RenderStates(const BlendMode &amp;theBlendMode, const Transform &amp;theTransform, const Texture *theTexture, const Shader *theShader)']]],
   ['rendertarget_10',['RenderTarget',['../classsf_1_1RenderTarget.html#a2997c96cbd93cb8ce0aba2ddae35b86f',1,'sf::RenderTarget']]],
   ['rendertexture_11',['RenderTexture',['../classsf_1_1RenderTexture.html#a19ee6e5b4c40ad251803389b3953a9c6',1,'sf::RenderTexture']]],
-  ['renderwindow_12',['renderwindow',['../classsf_1_1RenderWindow.html#a839bbf336bdcafb084dafc3076fc9021',1,'sf::RenderWindow::RenderWindow()'],['../classsf_1_1RenderWindow.html#aebef983e01f677bf5a66cefc4d547647',1,'sf::RenderWindow::RenderWindow(VideoMode mode, const String &amp;title, Uint32 style=Style::Default, const ContextSettings &amp;settings=ContextSettings())'],['../classsf_1_1RenderWindow.html#a25c0af7d515e710b6eebc9c6be952aa5',1,'sf::RenderWindow::RenderWindow(WindowHandle handle, const ContextSettings &amp;settings=ContextSettings())']]],
+  ['renderwindow_12',['RenderWindow',['../classsf_1_1RenderWindow.html#a839bbf336bdcafb084dafc3076fc9021',1,'sf::RenderWindow::RenderWindow()'],['../classsf_1_1RenderWindow.html#aebef983e01f677bf5a66cefc4d547647',1,'sf::RenderWindow::RenderWindow(VideoMode mode, const String &amp;title, Uint32 style=Style::Default, const ContextSettings &amp;settings=ContextSettings())'],['../classsf_1_1RenderWindow.html#a25c0af7d515e710b6eebc9c6be952aa5',1,'sf::RenderWindow::RenderWindow(WindowHandle handle, const ContextSettings &amp;settings=ContextSettings())']]],
   ['replace_13',['replace',['../classsf_1_1String.html#ad460e628c287b0fa88deba2eb0b6744b',1,'sf::String::replace(std::size_t position, std::size_t length, const String &amp;replaceWith)'],['../classsf_1_1String.html#a82bbfee2bf23c641e5361ad505c07921',1,'sf::String::replace(const String &amp;searchFor, const String &amp;replaceWith)']]],
   ['request_14',['Request',['../classsf_1_1Http_1_1Request.html#a8e89d9e8ffcc1163259b35d79809a61c',1,'sf::Http::Request']]],
   ['requestfocus_15',['requestFocus',['../classsf_1_1WindowBase.html#a448770d2372d8df0a1ad6b1c7cce3c89',1,'sf::WindowBase']]],
@@ -20,7 +20,7 @@ var searchData=
   ['resetbuffer_17',['resetBuffer',['../classsf_1_1Sound.html#acb7289d45e06fb76b8292ac84beb82a7',1,'sf::Sound']]],
   ['resetglstates_18',['resetGLStates',['../classsf_1_1RenderTarget.html#aac7504990d27dada4bfe3c7866920765',1,'sf::RenderTarget']]],
   ['resize_19',['resize',['../classsf_1_1VertexArray.html#a0c0fe239e8f9a54e64d3bbc96bf548c0',1,'sf::VertexArray']]],
-  ['response_20',['response',['../classsf_1_1Ftp_1_1Response.html#af300fffd4862774102f978eb22f85d9b',1,'sf::Ftp::Response::Response()'],['../classsf_1_1Http_1_1Response.html#a2e51c89356fe6a007c448a841a9ec08c',1,'sf::Http::Response::Response()']]],
+  ['response_20',['Response',['../classsf_1_1Ftp_1_1Response.html#af300fffd4862774102f978eb22f85d9b',1,'sf::Ftp::Response::Response()'],['../classsf_1_1Http_1_1Response.html#a2e51c89356fe6a007c448a841a9ec08c',1,'sf::Http::Response::Response()']]],
   ['restart_21',['restart',['../classsf_1_1Clock.html#a123e2627f2943e5ecaa1db0c7df3231b',1,'sf::Clock']]],
   ['rotate_22',['rotate',['../classsf_1_1Transform.html#ad09ce22a1fb08709f66f30befc7b2e7b',1,'sf::Transform::rotate(float angle)'],['../classsf_1_1Transform.html#ad78237e81d1de866d1b3c040ad003971',1,'sf::Transform::rotate(float angle, float centerX, float centerY)'],['../classsf_1_1Transform.html#a11aa9a4fbd9254e7d22b96f92f018d09',1,'sf::Transform::rotate(float angle, const Vector2f &amp;center)'],['../classsf_1_1Transformable.html#af8a5ffddc0d93f238fee3bf8efe1ebda',1,'sf::Transformable::rotate()'],['../classsf_1_1View.html#a5fd3901aae1845586ca40add94faa378',1,'sf::View::rotate()']]]
 ];
